%define _with_doc 0

Name:           jna
Version:        3.4.0
Release:        %mkrel 1
Summary:        Pure Java access to native libraries

Group:          Development/Java
License:        LGPLv2+
URL:            https://jna.dev.java.net/
# The source for this package was pulled from upstream's vcs. Use the
# following commands to generate the tarball:
#   svn export https://jna.dev.java.net/svn/jna/tags/%{version}/jnalib/ --username guest jna-%{version}
#   rm -rf jna-%{version}/dist/*
#   tar cjf ~/rpm/SOURCES/jna-%{version}.tar.bz2 jna-%{version}
Source0:        %name-%version.tar.bz2
Source1:	%{name}-pom.xml
Source2:        %{name}-platform-pom.xml
# This patch is Fedora-specific for now until we get the huge
# JNI library location mess sorted upstream
Patch1:         jna-3.4.0-loadlibrary.patch
# The X11 tests currently segfault; overall I think the X11 JNA stuff is just a 
# Really Bad Idea, for relying on AWT internals, using the X11 API at all,
# and using a complex API like X11 through JNA just increases the potential
# for problems.
Patch2:         jna-3.4.0-tests-headless.patch
Patch3:         jna-3.2.7-javadoc.patch
# Build using GCJ javadoc
Patch4:         jna-3.2.7-gcj-javadoc.patch
# junit cames from rpm
Patch5:         jna-3.4.0-junit.patch
# We manually require libffi because find-requires doesn't work
# inside jars.
Requires:       java  >= 0:1.6.0
Requires:       jpackage-utils, libffi
Requires(post):	jpackage-utils
Requires(postun): jpackage-utils
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  jpackage-utils, libffi-devel
BuildRequires:  ant, ant-junit, ant-nodeps, ant-trax, junit
BuildRequires:  libx11-devel, libxt-devel

%description
JNA provides Java programs easy access to native shared libraries
(DLLs on Windows) without writing anything but Java code. JNA's
design aims to provide native access in a natural way with a
minimum of effort. No boilerplate or generated code is required.
While some attention is paid to performance, correctness and ease
of use take priority.

%files
%{_libdir}/%{name}
%{_javadir}/%{name}.jar
%{_mavenpomdir}/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

#--------------------------------------------------------------------

%if %_with_doc
%package        javadoc
Summary:        Javadocs for %{name}
Group:          Development/Java
Requires:       %{name} = %{version}-%{release}

%description    javadoc
This package contains the javadocs for %{name}.

%files javadoc
%{_javadocdir}/%{name}-%{version}
%endif

#--------------------------------------------------------------------


%package        contrib
Summary:        Contrib for %{name}
Group:          Development/Java
Requires:       %{name} = %{version}-%{release}
Obsoletes:      %{name}-examples

%description    contrib
This package contains the contributed examples for %{name}.

%files contrib
%{_javadir}/%{name}
%{_mavenpomdir}/JPP.jna-platform.pom

#--------------------------------------------------------------------


%prep
%setup -q -n %name-%version
sed -e 's|@JNIPATH@|%{_libdir}/%{name}|' %{PATCH1} | patch -p1
%patch2 -p1 -b .tests-headless
#%patch3 -p1 -b .javadoc
# temporary hach for patch3 on epel5
#chmod -Rf a+rX,u+w,g-w,o-w .
#%patch4 -p0 -b .gcj-javadoc
%patch5 -p1 -b .junit
cp %{SOURCE1} ./
cp %{SOURCE2} ./
# UnloadTest fail during build since we modify class loading
rm test/com/sun/jna/JNAUnloadTest.java
# current bug: https://jna.dev.java.net/issues/show_bug.cgi?id=155
rm test/com/sun/jna/DirectTest.java

# all java binaries must be removed from the sources
#find . -name '*.jar' -delete
rm lib/junit.jar
find . -name '*.class' -delete

# remove internal copy of libffi
rm -rf native/libffi

%build
# We pass -Ddynlink.native which comes from our patch because
# upstream doesn't want to default to dynamic linking.
ant -Dcflags_extra.native="%{optflags}" -Ddynlink.native=true -Dnomixedjar.native=true jar contrib-jars
# remove compiled contribs
find contrib -name build -exec rm -rf {} \; || :
sed -i "s/VERSION/%{version}/" %{name}-pom.xml
sed -i "s/VERSION/%{version}/" %{name}-platform-pom.xml

%install
# jars
install -D -m 644 build*/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar
install -d -m 755 %{buildroot}%{_javadir}/%{name}
find contrib -name '*.jar' -exec cp {} %{buildroot}%{_javadir}/%{name}/ \;
# NOTE: JNA has highly custom code to look for native jars in this
# directory.  Since this roughly matches the jpackage guidelines,
# we'll leave it unchanged.
install -d -m 755 %{buildroot}%{_libdir}/%{name}
install -m 755 build*/native/libjnidispatch*.so %{buildroot}%{_libdir}/%{name}/

# install maven pom file
install -Dm 644 %{name}-pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
install -Dm 644 %{name}-platform-pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-platform.pom
# ... and maven depmap
%add_maven_depmap JPP-%{name}.pom %{name}.jar
%add_maven_depmap JPP.%{name}-platform.pom %name/platform.jar

%if %_with_doc
# javadocs
install -p -d -m 755 %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -a doc/javadoc/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%endif


%changelog

* Thu Jan 05 2012 dmorgan <dmorgan> 3.4.0-1.mga2
+ Revision: 190894
- Remove now useless macros
- Fix use of new maven macros
- New version 3.4.0

* Wed Oct 19 2011 dmorgan <dmorgan> 3.2.7-3.mga2
+ Revision: 156647
+ rebuild (emptylog)

* Wed Mar 30 2011 dmorgan <dmorgan> 3.2.7-3.mga1
+ Revision: 79004
- Rebuild against new libffi

* Tue Mar 29 2011 dmorgan <dmorgan> 3.2.7-2.mga1
+ Revision: 78953
- Rebuild against the correct libffi

* Mon Mar 21 2011 dmorgan <dmorgan> 3.2.7-1.mga1
+ Revision: 75154
- Fix java version
- Fix file list

  + saispo <saispo>
    - Fix Requires and BuildRequires
    - imported package jna

